@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.22'; # VERSION
 
 use File::HomeDir;
 use HTTP::Daemon;
@@ -554,17 +554,18 @@ sub access_log {
     }
     my $logline = sprintf(
         "%s - %s [%s] \"%s %s\" %d %s \"%s\" \"%s\"\n",
-        $self->{_sock_peerhost},
+        $self->{_sock_peerhost} // "-",
         "-", # XXX auth user
         POSIX::strftime("%d/%b/%Y:%H:%M:%S +0000",
                         gmtime($self->{_finish_req_time}[0])),
         $req->method,
         __escape_quote($req->uri->as_string),
-        $self->{_res_status},
+        $self->{_res_status} // 0,
         $self->{_res_content_length} // "-",
         scalar($reqh->header("referer")) // "-",
         scalar($reqh->header("user-agent")) // "-",
     );
+    #$log->tracef("logline=%s", $logline);
     if ($self->daemonize) {
         syswrite($self->_daemon->{_access_log}, $logline);
     } elsif (!defined($ENV{PLACK_ENV})) {
@@ -585,7 +586,7 @@ Gepok - PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
